'use strict';

var fs = require('fs');
var getbabelRelayPlugin = require('babel-relay-plugin');
var config = require('../config.tmp.json');
var Logger = require('./logger');

var lastSchema = '';
var adapter = void 0;
var initRef = void 0;

function getAdapter() {
  var schemaPath = config.schema.json;

  if (!fs.existsSync(schemaPath)) {
    Logger.debug('Schema no\'t found at: ' + schemaPath);
    return null;
  }

  delete require.cache[require.resolve(schemaPath)];
  var schema = require(schemaPath);
  var schemaString = JSON.stringify(schema.data);

  // Verify if json have changed and create a new adapter
  if (schemaString !== lastSchema) {
    Logger.debug('Creating a new adapter...');
    lastSchema = schemaString;
    adapter = getbabelRelayPlugin(schema.data)(initRef);
  }

  return adapter;
}

module.exports = function (_ref) {
  initRef = _ref;
  return {
    visitor: {
      Program: function Program(_ref2, state) {
        var adapter = getAdapter();
        if (adapter) {
          adapter.visitor.Program(_ref2, state);
        }
      },
      TaggedTemplateExpression: function TaggedTemplateExpression(path, state) {
        var adapter = getAdapter();
        if (adapter) {
          getAdapter().visitor.TaggedTemplateExpression(path, state);
        }
      }
    }
  };
};